@@ -11,14 +11,11 @@ def get_traceback():
 
 pysite_logger = None
 
-def logger(sitedir):
+def logger(conf):
 	global pysite_logger
 	if not pysite_logger:
-		conf = imp.load_source('conf',join(sitedir,'conf.py'))
-		log_filename = 'site.log'
-		if 'logfile' in conf.conf:
-			log_filename = conf.conf['logfile']
-		pysite_logger = logging.getLogger('mv-login')
+		log_filename = conf.logfile
+		pysite_logger = logging.getLogger(conf.sitename)
 		pysite_logger.setLevel(logging.DEBUG)
 
 		# Add the log message handler to the logger
